@@ -330,6 +330,11 @@ DCStartd::deactivateClaim( bool graceful, bool *claim_is_closing )
 	ClaimIdParser cidp(claim_id);
 	char const *sec_session = cidp.secSessionId();
 
+	if (IsDebugLevel(D_COMMAND)) {
+		int cmd = graceful ? DEACTIVATE_CLAIM : DEACTIVATE_CLAIM_FORCIBLY;
+		dprintf (D_COMMAND, "DCStartd::deactivateClaim(%s,...) making connection to %s\n", getCommandStringSafe(cmd), _addr ? _addr : "NULL");
+	}
+
 	bool  result;
 	ReliSock reli_sock;
 	reli_sock.timeout(20);   // years of research... :)
@@ -614,6 +619,17 @@ DCStartd::requestClaim( ClaimType cType, const ClassAd* req_ad,
 }
 
 
+bool
+DCStartd::updateMachineAd( const ClassAd * update, ClassAd * reply, int timeout ) {
+	setCmdStr( "updateMachineAd" );
+
+	ClassAd u( * update );
+	u.Assign( ATTR_COMMAND, getCommandString( CA_UPDATE_MACHINE_AD ) );
+
+	return sendCACmd( & u, reply, true, timeout );
+}
+
+
 bool
 DCStartd::activateClaim( const ClassAd* job_ad, ClassAd* reply, 
 						 int timeout ) 
@@ -915,6 +931,11 @@ DCStartd::vacateClaim( const char* name_vacate )
 {
 	setCmdStr( "vacateClaim" );
 
+	if (IsDebugLevel(D_COMMAND)) {
+		int cmd = VACATE_CLAIM;
+		dprintf (D_COMMAND, "DCStartd::vacateClaim(%s,...) making connection to %s\n", getCommandStringSafe(cmd), _addr ? _addr : "NULL");
+	}
+
 	bool  result;
 	ReliSock reli_sock;
 	reli_sock.timeout(20);   // years of research... :)
@@ -966,6 +987,11 @@ DCStartd::_suspendClaim( )
 	ClaimIdParser cidp(claim_id);
 	char const *sec_session = cidp.secSessionId();
 	
+	if (IsDebugLevel(D_COMMAND)) {
+		int cmd = SUSPEND_CLAIM;
+		dprintf (D_COMMAND, "DCStartd::_suspendClaim(%s,...) making connection to %s\n", getCommandStringSafe(cmd), _addr ? _addr : "NULL");
+	}
+
 	bool  result;
 	ReliSock reli_sock;
 	reli_sock.timeout(20);   // years of research... :)
@@ -1019,6 +1045,11 @@ DCStartd::_continueClaim( )
 	ClaimIdParser cidp(claim_id);
 	char const *sec_session = cidp.secSessionId();
 	
+	if (IsDebugLevel(D_COMMAND)) {
+		int cmd = CONTINUE_CLAIM;
+		dprintf (D_COMMAND, "DCStartd::_continueClaim(%s,...) making connection to %s\n", getCommandStringSafe(cmd), _addr ? _addr : "NULL");
+	}
+
 	bool  result;
 	ReliSock reli_sock;
 	reli_sock.timeout(20);   // years of research... :)
@@ -1065,6 +1096,11 @@ DCStartd::checkpointJob( const char* name_ckpt )
 
 	setCmdStr( "checkpointJob" );
 
+	if (IsDebugLevel(D_COMMAND)) {
+		int cmd = PCKPT_JOB;
+		dprintf (D_COMMAND, "DCStartd::checkpointJob(%s,...) making connection to %s\n", getCommandStringSafe(cmd), _addr ? _addr : "NULL");
+	}
+
 	bool  result;
 	ReliSock reli_sock;
 	reli_sock.timeout(20);   // years of research... :)
